@@ -12,7 +12,7 @@
 from cqrcode.view.GUI_welcome import hello
 
 while True:
-    x = input('type 's' to start...（target figure saves in ~.\Lib\site-packages\cqrcode\static\）\n')
+    x = input("""type 's' to start...（target figure saves in ~.\Lib\site-packages\cqrcode\static\）\n""")
     if x == 's' or x == 'S':
         hello()
     else:
